@@ -1,4 +1,4 @@
-from filer.settings import FILER_ADMIN_ICON_SIZES, FILER_MEDIA_PREFIX
+from filer.settings import FILER_ADMIN_ICON_SIZES, FILER_STATICMEDIA_PREFIX
 
 class IconsMixin(object):
     '''
@@ -10,5 +10,5 @@ class IconsMixin(object):
         r = {}
         if getattr(self, '_icon', False):
             for size in FILER_ADMIN_ICON_SIZES:
-                r[size] = "%sicons/%s_%sx%s.png" % (FILER_MEDIA_PREFIX, self._icon, size, size)
+                r[size] = "%sicons/%s_%sx%s.png" % (FILER_STATICMEDIA_PREFIX, self._icon, size, size)
         return r
\ No newline at end of file
